@@ -15,7 +15,6 @@ describe 'glance::registry' do
       :enabled                => true,
       :manage_service         => true,
       :purge_config           => false,
-      :os_region_name         => '<SERVICE DEFAULT>',
       :ca_file                => '<SERVICE DEFAULT>',
       :cert_file              => '<SERVICE DEFAULT>',
       :key_file               => '<SERVICE DEFAULT>',
@@ -30,7 +29,6 @@ describe 'glance::registry' do
         :bind_port              => '9111',
         :workers                => '5',
         :enabled                => false,
-        :os_region_name         => 'RegionOne2',
       }
     ].each do |param_set|
 
@@ -74,13 +72,6 @@ describe 'glance::registry' do
             is_expected.to contain_glance_registry_config("paste_deploy/flavor").with_value('keystone')
           end
         end
-        it 'is_expected.to lay down default glance_store registry config' do
-          [
-            'os_region_name',
-          ].each do |config|
-            is_expected.to contain_glance_registry_config("glance_store/#{config}").with_value(param_hash[config.intern])
-          end
-        end
         it 'is_expected.to lay down default ssl config' do
           [
             'ca_file',
@@ -150,7 +141,7 @@ describe 'glance::registry' do
         end
 
         it { expect { is_expected.to contain_glance_registry_config('filter:paste_deploy/flavor') }.to\
-          raise_error(Puppet::Error, /validate_re\(\): .* does not match/) }
+          raise_error(Puppet::Error) }
       end
     end
 
